@@ -246,7 +246,6 @@ def test_get_requires_for_build_wheel(config_settings, repo_root):
     expected_requirements = [
         "colorama",
         "docutils",
-        "cryptography",
         "ruamel.yaml",
         "ruamel.yaml.clib",
         "prompt-toolkit",
@@ -255,6 +254,7 @@ def test_get_requires_for_build_wheel(config_settings, repo_root):
         "python-dateutil",
         "jmespath",
         "urllib3",
+        "wcwidth",
     ]
     assert len(expected_requirements) == len(requirements)
     for expected_requirement in expected_requirements:
