@@ -12,6 +12,7 @@
 # language governing permissions and limitations under the License.
 import pytest
 from botocore.config import Config
+from botocore.handlers import get_bearer_auth_supported_services
 
 from tests import create_session, mock
 
@@ -24,6 +25,10 @@ from tests import create_session, mock
 # by manually assigning a signer when credentials are unavailable. To avoid
 # false positives, we filter these services out of the tests below.
 
+# Some services (such as Bedrock) have customizations that bypass this limitation
+# by manually assigning a signer when credentials are unavailable. To avoid
+# false positives, we filter these services out of the tests below.
+
 
 # The dictionary's value here needs to be hashable to be added to the set below; any
 # new auth types with multiple requirements should be added in a comma-separated list
@@ -36,11 +41,10 @@ AUTH_TYPE_REQUIREMENTS = {
 
 # Services with a `signing_name` that are known to have
 # customizations for handling mixed authentication methods.
-# TODO: Replace with get_bearer_auth_supported_services()
-#  from botocore.handlers once it's ported over.
-KNOWN_MIXED_AUTH_SERVICES = {'bedrock'}
+KNOWN_MIXED_AUTH_SERVICES = get_bearer_auth_supported_services()
 KNOWN_MIXED_AUTH_SCHEMES = {'aws.auth#sigv4', 'smithy.api#httpBearerAuth'}
 
+
 def _all_test_cases():
     session = create_session()
     loader = session.get_component('data_loader')
@@ -70,8 +74,16 @@ AUTH_SERVICES, AUTH_OPERATIONS = _all_test_cases()
 
 
 @pytest.mark.validates_models
-@pytest.mark.parametrize("auth_service, auth_config", AUTH_SERVICES)
-def test_all_requirements_match_for_service(auth_service, auth_config):
+@pytest.mark.parametrize(
+    "auth_service, auth_config",
+    AUTH_SERVICES
+)
+def test_all_requirements_match_for_service(
+        auth_service,
+        auth_config,
+        record_property
+):
+    record_property("aws_service", auth_service)
     # Validates that all service-level signature types have the same requirements
     message = f'Found mixed signer requirements for service: {auth_service}'
     assert_all_requirements_match(auth_config, message)
@@ -79,7 +91,9 @@ def test_all_requirements_match_for_service(auth_service, auth_config):
 
 @pytest.mark.validates_models
 @pytest.mark.parametrize("auth_service, operation_model", AUTH_OPERATIONS)
-def test_all_requirements_match_for_operation(auth_service, operation_model):
+def test_all_requirements_match_for_operation(auth_service, operation_model, record_property):
+    record_property("aws_service", operation_model.service_model.service_name)
+    record_property("aws_operation", operation_model.name)
     # Validates that all operation-level signature types have the same requirements
     message = f'Found mixed signer requirements for operation: {auth_service}.{operation_model.name}'
     auth_config = operation_model.auth
