@@ -16,7 +16,7 @@ from awscrt.s3 import S3RequestType
 
 from awscli.compat import BytesIO
 from awscli.customizations.s3.utils import relative_path
-from awscli.testutils import cd, mock
+from awscli.testutils import cd, mock, skip_if_case_sensitive, skip_if_windows
 from tests.functional.s3 import (
     BaseCRTTransferClientTest,
     BaseS3CLIRunnerTest,
@@ -542,6 +542,91 @@ class TestSyncCommand(BaseS3TransferCommandTest):
             ('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items()
         )
 
+    def test_sync_upload_with_no_overwrite_when_file_does_not_exist_at_destination(
+        self,
+    ):
+        self.files.create_file("new_file.txt", "mycontent")
+        self.parsed_responses = [
+            self.list_objects_response(['file.txt']),
+            {'ETag': '"c8afdb36c52cf4727836669019e69222"'},
+        ]
+        cmdline = (
+            f'{self.prefix} {self.files.rootdir} s3://bucket --no-overwrite'
+        )
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 2)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+        self.assertEqual(self.operations_called[1][0].name, 'PutObject')
+        self.assertEqual(self.operations_called[1][1]['Key'], 'new_file.txt')
+
+    def test_sync_upload_with_no_overwrite_when_file_exists_at_destination(
+        self,
+    ):
+        self.files.create_file("new_file.txt", "mycontent")
+        self.parsed_responses = [
+            self.list_objects_response(['new_file.txt']),
+        ]
+        cmdline = (
+            f'{self.prefix} {self.files.rootdir} s3://bucket --no-overwrite'
+        )
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 1)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+
+    def test_sync_download_with_no_overwrite_file_not_exists_at_destination(
+        self,
+    ):
+        self.parsed_responses = [
+            self.list_objects_response(['new_file.txt']),
+            self.get_object_response(),
+        ]
+        cmdline = (
+            f'{self.prefix} s3://bucket/ {self.files.rootdir} --no-overwrite'
+        )
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 2)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+        self.assertEqual(self.operations_called[1][0].name, 'GetObject')
+        local_file_path = os.path.join(self.files.rootdir, 'new_file.txt')
+        self.assertTrue(os.path.exists(local_file_path))
+
+    def test_sync_download_with_no_overwrite_file_exists_at_destination(self):
+        self.files.create_file('file.txt', 'My content')
+        self.parsed_responses = [
+            self.list_objects_response(['file.txt']),
+        ]
+        cmdline = (
+            f'{self.prefix} s3://bucket/ {self.files.rootdir} --no-overwrite'
+        )
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 1)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+
+    def test_sync_copy_with_no_overwrite_file_not_exists_at_destination(self):
+        self.parsed_responses = [
+            self.list_objects_response(['new_file.txt']),
+            self.list_objects_response(['file1.txt']),
+            self.copy_object_response(),
+        ]
+        cmdline = f'{self.prefix} s3://bucket/ s3://bucket2/ --no-overwrite'
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 3)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+        self.assertEqual(self.operations_called[1][0].name, 'ListObjectsV2')
+        self.assertEqual(self.operations_called[2][0].name, 'CopyObject')
+        self.assertEqual(self.operations_called[2][1]['Key'], 'new_file.txt')
+
+    def test_sync_copy_with_no_overwrite_file_exists_at_destination(self):
+        self.parsed_responses = [
+            self.list_objects_response(['new_file.txt']),
+            self.list_objects_response(['new_file.txt', 'file1.txt']),
+        ]
+        cmdline = f'{self.prefix} s3://bucket/ s3://bucket2/ --no-overwrite'
+        self.run_cmd(cmdline, expected_rc=0)
+        self.assertEqual(len(self.operations_called), 2)
+        self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+        self.assertEqual(self.operations_called[1][0].name, 'ListObjectsV2')
+
 
 class TestSyncSourceRegion(BaseS3CLIRunnerTest):
     def test_respects_source_region(self):
@@ -736,3 +821,110 @@ class TestSyncCommandWithS3Express(BaseS3TransferCommandTest):
         # Just asserting that command validated and made an API call
         self.assertEqual(len(self.operations_called), 1)
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
+
+
+class TestSyncCaseConflict(BaseS3TransferCommandTest):
+    prefix = 's3 sync '
+
+    def setUp(self):
+        super().setUp()
+        self.lower_key = 'a.txt'
+        self.upper_key = 'A.txt'
+
+    @skip_if_case_sensitive()
+    def test_error_with_existing_file(self):
+        self.files.create_file(self.lower_key, 'mycontent')
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict error"
+        )
+        self.parsed_responses = [self.list_objects_response([self.upper_key])]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=1)
+        assert f"Failed to download bucket/{self.upper_key}" in stderr
+
+    def test_error_with_case_conflicts_in_s3(self):
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict error"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key, self.lower_key])
+        ]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=1)
+        assert f"Failed to download bucket/{self.lower_key}" in stderr
+
+    @skip_if_case_sensitive()
+    def test_warn_with_existing_file(self):
+        self.files.create_file(self.lower_key, 'mycontent')
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict warn"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key]),
+            self.get_object_response(),
+        ]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        assert f"warning: Downloading bucket/{self.upper_key}" in stderr
+
+    @skip_if_windows("Can't rename to same file")
+    def test_warn_with_case_conflicts_in_s3(self):
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict warn"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key, self.lower_key]),
+            self.get_object_response(),
+            self.get_object_response(),
+        ]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        assert f"warning: Downloading bucket/{self.lower_key}" in stderr
+
+    @skip_if_case_sensitive()
+    def test_skip_with_existing_file(self):
+        self.files.create_file(self.lower_key, 'mycontent')
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict skip"
+        )
+        self.parsed_responses = [self.list_objects_response([self.upper_key])]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        assert f"warning: Skipping bucket/{self.upper_key}" in stderr
+
+    def test_skip_with_case_conflicts_in_s3(self):
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict skip"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key, self.lower_key]),
+            self.get_object_response(),
+        ]
+        _, stderr, _ = self.run_cmd(cmd, expected_rc=0)
+        assert f"warning: Skipping bucket/{self.lower_key}" in stderr
+
+    def test_ignore_with_existing_file(self):
+        self.files.create_file(self.lower_key, 'mycontent')
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict ignore"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key]),
+            self.get_object_response(),
+        ]
+        self.run_cmd(cmd, expected_rc=0)
+
+    @skip_if_windows("Can't rename to same file")
+    def test_ignore_with_case_conflicts_in_s3(self):
+        cmd = (
+            f"{self.prefix} s3://bucket {self.files.rootdir} "
+            "--case-conflict ignore"
+        )
+        self.parsed_responses = [
+            self.list_objects_response([self.upper_key, self.lower_key]),
+            self.get_object_response(),
+            self.get_object_response(),
+        ]
+        self.run_cmd(cmd, expected_rc=0)
