@@ -14,6 +14,7 @@ import copy
 
 from botocore.exceptions import ClientError
 from botocore.stub import Stubber
+from s3transfer.copies import CopySubmissionTask
 from s3transfer.exceptions import S3CopyFailedError
 from s3transfer.manager import TransferConfig, TransferManager
 from s3transfer.utils import MIN_UPLOAD_CHUNKSIZE
@@ -254,6 +255,69 @@ class TestNonMultipartCopy(BaseCopyTest):
         future.result()
         self.stubber.assert_no_pending_responses()
 
+    def test_copy_with_ifnonematch_when_object_not_exists_at_target(self):
+        self.extra_args['IfNoneMatch'] = '*'
+
+        expected_head_params = {
+            'Bucket': 'mysourcebucket',
+            'Key': 'mysourcekey',
+        }
+
+        expected_copy_object = {
+            'Bucket': 'mybucket',
+            'Key': 'mykey',
+            'CopySource': {
+                'Bucket': 'mysourcebucket', 
+                'Key': 'mysourcekey',
+            },
+            "IfNoneMatch": "*"
+        }
+
+        self.add_head_object_response(expected_params=expected_head_params)
+        self.add_successful_copy_responses(
+            expected_copy_params=expected_copy_object
+        )
+
+        call_kwargs = self.create_call_kwargs()
+        call_kwargs['extra_args'] = self.extra_args
+        future = self.manager.copy(**call_kwargs)
+        future.result()
+        self.stubber.assert_no_pending_responses()
+
+    def test_copy_with_ifnonematch_when_object_exists_at_target(self):
+        self.extra_args['IfNoneMatch'] = '*'
+
+        expected_head_params = {
+            'Bucket': 'mysourcebucket',
+            'Key': 'mysourcekey',
+        }
+
+        self.add_head_object_response(expected_params=expected_head_params)
+
+        # Mock a PreconditionFailed error for copy_object
+        self.stubber.add_client_error(
+            method='copy_object',
+            service_error_code='PreconditionFailed',
+            service_message='The condition specified in the conditional header(s) was not met',
+            http_status_code=412,
+            expected_params={
+                'Bucket': self.bucket,
+                'Key': self.key,
+                'CopySource': self.copy_source,
+                'IfNoneMatch': '*',
+            },
+        )
+
+        call_kwargs = self.create_call_kwargs()
+        call_kwargs['extra_args'] = self.extra_args
+        future = self.manager.copy(**call_kwargs)
+        with self.assertRaises(ClientError) as context:
+            future.result()
+        self.assertEqual(
+            context.exception.response['Error']['Code'], 'PreconditionFailed'
+        )
+        self.stubber.assert_no_pending_responses()
+
     def test_copy_maps_extra_args_to_head_object(self):
         self.extra_args['CopySourceSSECustomerAlgorithm'] = 'AES256'
 
@@ -282,8 +346,8 @@ class TestNonMultipartCopy(BaseCopyTest):
 
     def test_allowed_copy_params_are_valid(self):
         op_model = self.client.meta.service_model.operation_model('CopyObject')
-        for allowed_upload_arg in self._manager.ALLOWED_COPY_ARGS:
-            self.assertIn(allowed_upload_arg, op_model.input_shape.members)
+        for allowed_copy_arg in self._manager.ALLOWED_COPY_ARGS:
+            self.assertIn(allowed_copy_arg, op_model.input_shape.members)
 
     def test_copy_with_tagging(self):
         extra_args = {'Tagging': 'tag1=val1', 'TaggingDirective': 'REPLACE'}
@@ -713,6 +777,90 @@ class TestMultipartCopy(BaseCopyTest):
         future.result()
         self.stubber.assert_no_pending_responses()
 
+    def test_copy_with_ifnonematch_when_large_object_exists_at_target(
+        self,
+    ):
+        # Set up IfNoneMatch in extra_args
+        self.extra_args['IfNoneMatch'] = '*'
+        # Add head object response
+        self.add_get_head_response_with_default_expected_params()
+        # Should use multipart upload
+        self.add_create_multipart_response_with_default_expected_params()
+        self.add_upload_part_copy_responses_with_default_expected_params()
+        # Mock a PreconditionFailed error for complete_multipart_upload
+        self.stubber.add_client_error(
+            method='complete_multipart_upload',
+            service_error_code='PreconditionFailed',
+            service_message='The condition specified in the conditional header(s) was not met',
+            http_status_code=412,
+            expected_params={
+                'Bucket': self.bucket,
+                'Key': self.key,
+                'UploadId': self.multipart_id,
+                'MultipartUpload': {
+                    'Parts': [
+                        {'ETag': 'etag-1', 'PartNumber': 1},
+                        {'ETag': 'etag-2', 'PartNumber': 2},
+                        {'ETag': 'etag-3', 'PartNumber': 3},
+                    ]
+                },
+                'IfNoneMatch': '*',
+            },
+        )
+        # Add abort_multipart_upload response
+        self.stubber.add_response(
+            'abort_multipart_upload',
+            service_response={},
+            expected_params={
+                'Bucket': self.bucket,
+                'Key': self.key,
+                'UploadId': self.multipart_id,
+            },
+        )
+        call_kwargs = self.create_call_kwargs()
+        call_kwargs['extra_args'] = self.extra_args
+        future = self.manager.copy(**call_kwargs)
+        with self.assertRaises(ClientError) as context:
+            future.result()
+        self.assertEqual(
+            context.exception.response['Error']['Code'], 'PreconditionFailed'
+        )
+        self.stubber.assert_no_pending_responses()
+
+    def test_copy_with_ifnonematch_when_large_object_not_exists_at_target(
+        self,
+    ):
+        # Set up IfNoneMatch in extra_args
+        self.extra_args['IfNoneMatch'] = '*'
+        # Add head object response
+        self.add_get_head_response_with_default_expected_params()
+        # Should use multipart upload
+        self.add_create_multipart_response_with_default_expected_params()
+        self.add_upload_part_copy_responses_with_default_expected_params()
+        # Add successful complete_multipart_upload response
+        self.stubber.add_response(
+            'complete_multipart_upload',
+            service_response={},
+            expected_params={
+                'Bucket': self.bucket,
+                'Key': self.key,
+                'UploadId': self.multipart_id,
+                'MultipartUpload': {
+                    'Parts': [
+                        {'ETag': 'etag-1', 'PartNumber': 1},
+                        {'ETag': 'etag-2', 'PartNumber': 2},
+                        {'ETag': 'etag-3', 'PartNumber': 3},
+                    ]
+                },
+                'IfNoneMatch': '*',
+            },
+        )
+        call_kwargs = self.create_call_kwargs()
+        call_kwargs['extra_args'] = self.extra_args
+        future = self.manager.copy(**call_kwargs)
+        future.result()
+        self.stubber.assert_no_pending_responses()
+
     def test_copy_fails_if_etag_validation_fails(self):
         expected_params = {
             'Bucket': 'mybucket',
