@@ -11,7 +11,6 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import os
-import random
 import re
 import shutil
 import signal
@@ -24,6 +23,7 @@ from awscli.clidriver import create_clidriver
 from awscli.testutils import (
     BaseS3CLICommand,
     aws,
+    random_bucket_name,
     skip_if_windows,
     temporary_file,
     unittest,
@@ -126,11 +126,11 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         self.assertEqual(p.stderr, '')
 
     def test_help_with_warning_blocks(self):
-        p = aws('elastictranscoder create-pipeline help')
+        p = aws('bedrock-runtime invoke-model help')
         self.assertEqual(p.rc, 0, p.stderr)
         # Check text that appears in the warning block to ensure
         # the block was actually rendered.
-        self.assertRegex(p.stdout, r'To\s+receive\s+notifications')
+        self.assertRegex(p.stdout, r"To\s+deny\s+all\s+inference\s+access")
 
     def test_param_shorthand(self):
         p = aws(
@@ -156,7 +156,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         self.assertIn(
             "The filter 'bad-filter' is invalid",
             p.stderr,
-            "stdout: %s, stderr: %s" % (p.stdout, p.stderr),
+            f"stdout: {p.stdout}, stderr: {p.stderr}",
         )
 
     def test_param_with_file(self):
@@ -166,23 +166,20 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         with open(param_file, 'w') as f:
             f.write('[{"Name": "instance-id", "Values": ["i-123"]}]')
         self.addCleanup(os.remove, param_file)
-        p = aws('ec2 describe-instances --filters file://%s' % param_file)
+        p = aws(f'ec2 describe-instances --filters file://{param_file}')
         self.assertEqual(p.rc, 0)
         self.assertIn('Reservations', p.json)
 
     def test_streaming_output_operation(self):
         d = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, d)
-        bucket_name = (
-            'clistream' + str(int(time.time())) + str(random.randint(1, 100))
-        )
+        bucket_name = random_bucket_name('clistream')
 
         self.put_object(
             bucket=bucket_name, key='foobar', content='foobar contents'
         )
         p = aws(
-            's3api get-object --bucket %s --key foobar %s'
-            % (bucket_name, os.path.join(d, 'foobar'))
+            f's3api get-object --bucket {bucket_name} --key foobar {os.path.join(d, "foobar")}'
         )
         self.assertEqual(p.rc, 0)
         with open(os.path.join(d, 'foobar')) as f:
@@ -197,9 +194,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         env_vars['AWS_ACCESS_KEY_ID'] = 'foo'
         env_vars['AWS_SECRET_ACCESS_KEY'] = 'bar'
 
-        bucket_name = (
-            'nosign' + str(int(time.time())) + str(random.randint(1, 100))
-        )
+        bucket_name = random_bucket_name('nosign')
         self.put_object(
             bucket_name,
             'foo',
@@ -208,16 +203,15 @@ class TestBasicCommandFunctionality(unittest.TestCase):
         )
 
         p = aws(
-            's3api get-object --bucket %s --key foo %s'
-            % (bucket_name, os.path.join(d, 'foo')),
+            f's3api get-object --bucket {bucket_name} --key foo {os.path.join(d, "foo")}',
             env_vars=env_vars,
         )
         # Should have credential issues.
         self.assertEqual(p.rc, 254)
 
         p = aws(
-            's3api get-object --bucket %s --key foo '
-            '%s --no-sign-request' % (bucket_name, os.path.join(d, 'foo')),
+            f's3api get-object --bucket {bucket_name} --key foo '
+            f'{os.path.join(d, "foo")} --no-sign-request',
             env_vars=env_vars,
         )
 
@@ -231,17 +225,15 @@ class TestBasicCommandFunctionality(unittest.TestCase):
     def test_no_paginate_arg(self):
         d = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, d)
-        bucket_name = (
-            'nopaginate' + str(int(time.time())) + str(random.randint(1, 100))
-        )
+        bucket_name = random_bucket_name('nopaginate')
 
         self.put_object(
             bucket=bucket_name, key='foobar', content='foobar contents'
         )
-        p = aws('s3api list-objects --bucket %s --no-paginate' % bucket_name)
+        p = aws(f's3api list-objects --bucket {bucket_name} --no-paginate')
         self.assertEqual(p.rc, 0, p.stdout + p.stderr)
 
-        p = aws('s3api list-objects --bucket %s' % bucket_name)
+        p = aws(f's3api list-objects --bucket {bucket_name}')
         self.assertEqual(p.rc, 0, p.stdout + p.stderr)
 
     def test_top_level_options_debug(self):
@@ -261,7 +253,7 @@ class TestBasicCommandFunctionality(unittest.TestCase):
             '<subcommand> [<subcommand> ...] [parameters]',
             p.stderr,
         )
-        self.assertIn('aws: error', p.stderr)
+        self.assertIn('aws: [ERROR]', p.stderr)
 
     def test_help_usage_service_level(self):
         p = aws('ec2')
@@ -270,11 +262,11 @@ class TestBasicCommandFunctionality(unittest.TestCase):
             '<subcommand> [<subcommand> ...] [parameters]',
             p.stderr,
         )
-        # python3: aws: error: the following arguments are required: operation
-        # python2: aws: error: too few arguments
+        # python3: aws: [ERROR]: the following arguments are required: operation
+        # python2: aws: [ERROR]: too few arguments
         # We don't care too much about the specific error message, as long
         # as it says we have a parse error.
-        self.assertIn('aws: error', p.stderr)
+        self.assertIn('aws: [ERROR]', p.stderr)
 
     def test_help_usage_operation_level(self):
         p = aws('ec2 start-instances')
@@ -458,8 +450,8 @@ class TestGlobalArgs(BaseS3CLICommand):
         self.put_object(bucket_name, 'foo2.txt', contents=b'bar')
         self.put_object(bucket_name, 'foo3.txt', contents=b'bar')
         p = aws(
-            's3api list-objects --bucket %s '
-            '--no-paginate --output json' % bucket_name
+            f's3api list-objects --bucket {bucket_name} '
+            '--no-paginate --output json'
         )
         # A really simple way to check that --no-paginate was
         # honored is to see if we have all the mirrored input
@@ -476,8 +468,8 @@ class TestGlobalArgs(BaseS3CLICommand):
         self.put_object(bucket_name, 'foo2.txt', contents=b'bar')
         self.put_object(bucket_name, 'foo3.txt', contents=b'bar')
         p = aws(
-            's3api list-objects --bucket %s '
-            '--max-keys 1 --no-paginate --output json' % bucket_name
+            f's3api list-objects --bucket {bucket_name} '
+            '--max-keys 1 --no-paginate --output json'
         )
         self.assert_no_errors(p)
         response_json = p.json
@@ -489,8 +481,8 @@ class TestGlobalArgs(BaseS3CLICommand):
         self.put_object(bucket_name, 'foo2.txt', contents=b'bar')
         self.put_object(bucket_name, 'foo3.txt', contents=b'bar')
         p = aws(
-            's3api list-objects --bucket %s '
-            '--max-items 1 --output json' % bucket_name
+            f's3api list-objects --bucket {bucket_name} '
+            '--max-items 1 --output json'
         )
         self.assert_no_errors(p)
         response_json = p.json
@@ -500,8 +492,8 @@ class TestGlobalArgs(BaseS3CLICommand):
         bucket_name = self.create_bucket()
         self.put_object(bucket_name, 'foo.txt', contents=b'bar')
         p = aws(
-            's3api list-objects --bucket %s '
-            '--query Contents[].Key --output json' % bucket_name
+            f's3api list-objects --bucket {bucket_name} '
+            '--query Contents[].Key --output json'
         )
         self.assert_no_errors(p)
         response_json = p.json
@@ -522,8 +514,7 @@ class TestGlobalArgs(BaseS3CLICommand):
         env['AWS_ACCESS_KEY_ID'] = 'foo'
         env['AWS_SECRET_ACCESS_KEY'] = 'bar'
         p = aws(
-            's3api head-object --bucket %s --key public --no-sign-request'
-            % bucket_name,
+            f's3api head-object --bucket {bucket_name} --key public --no-sign-request',
             env_vars=env,
         )
         self.assert_no_errors(p)
@@ -532,8 +523,7 @@ class TestGlobalArgs(BaseS3CLICommand):
         # Should fail because we're not signing the request but the object is
         # private.
         p = aws(
-            's3api head-object --bucket %s --key private --no-sign-request'
-            % bucket_name,
+            f's3api head-object --bucket {bucket_name} --key private --no-sign-request',
             env_vars=env,
         )
         self.assertEqual(p.rc, 254)
