@@ -14,6 +14,7 @@ spec.  This can happen for a number of reasons:
 
 import base64
 import datetime
+import decimal
 import io
 import json
 
@@ -377,6 +378,79 @@ class TestJSONTimestampSerialization(unittest.TestCase):
         self.assertEqual(body['Timestamp'], 0)
 
 
+class TestJSONFloatSerialization(unittest.TestCase):
+    def setUp(self):
+        self.model = {
+            'metadata': {
+                'protocol': 'json',
+                'apiVersion': '2014-01-01',
+                'jsonVersion': '1.1',
+                'targetPrefix': 'foo',
+            },
+            'documentation': '',
+            'operations': {
+                'TestOperation': {
+                    'name': 'TestOperation',
+                    'http': {
+                        'method': 'POST',
+                        'requestUri': '/',
+                    },
+                    'input': {'shape': 'InputShape'},
+                }
+            },
+            'shapes': {
+                'InputShape': {
+                    'type': 'structure',
+                    'members': {
+                        'Double': {'shape': 'DoubleType'},
+                        'Float': {'shape': 'FloatType'},
+                    },
+                },
+                'DoubleType': {
+                    'type': 'double',
+                },
+                'FloatType': {
+                    'type': 'float',
+                },
+            },
+        }
+        self.service_model = ServiceModel(self.model)
+
+    def serialize_to_request(self, input_params):
+        request_serializer = serialize.create_serializer(
+            self.service_model.metadata['protocol']
+        )
+        return request_serializer.serialize_to_request(
+            input_params, self.service_model.operation_model('TestOperation')
+        )
+
+    def test_accepts_decimal_with_precision_above_floats(self):
+        float_string = '0.12345678901234567890'
+        float_as_float = float(
+            float_string
+        )  # This has less precision; it will be lost on serialization
+        float_as_decimal = decimal.Decimal(float_string)
+        body = json.loads(
+            self.serialize_to_request({'Float': float_as_decimal})[
+                'body'
+            ].decode('utf-8')
+        )
+        self.assertEqual(decimal.Decimal(body['Float']), float_as_float)
+
+    def test_accepts_decimal_with_precision_above_doubles(self):
+        double_string = '0.12345678901234567890'
+        double_as_float = float(
+            double_string
+        )  # This has less precision; it will be lost on serialization
+        double_as_decimal = decimal.Decimal(double_string)
+        body = json.loads(
+            self.serialize_to_request({'Double': double_as_decimal})[
+                'body'
+            ].decode('utf-8')
+        )
+        self.assertEqual(decimal.Decimal(body['Double']), double_as_float)
+
+
 class TestInstanceCreation(unittest.TestCase):
     def setUp(self):
         self.model = {
@@ -540,3 +614,54 @@ class TestRestXMLUnicodeSerialization(unittest.TestCase):
             self.serialize_to_request(params)
         except UnicodeEncodeError:
             self.fail("RestXML serializer failed to serialize unicode text.")
+
+class TestRpcV2CBORHostPrefix(unittest.TestCase):
+    def setUp(self):
+        self.model = {
+            'metadata': {
+                'protocol': 'smithy-rpc-v2-cbor',
+                'apiVersion': '2014-01-01',
+                'serviceId': 'MyService',
+                'targetPrefix': 'sampleservice',
+                'documentation': '',
+            },
+            'operations': {
+                'TestHostPrefixOperation': {
+                    'name': 'TestHostPrefixOperation',
+                    'input': {'shape': 'InputShape'},
+                    'endpoint': {'hostPrefix': '{Foo}'},
+                },
+                'TestNoHostPrefixOperation': {
+                    'name': 'TestNoHostPrefixOperation',
+                    'input': {'shape': 'InputShape'},
+                },
+            },
+            'shapes': {
+                'InputShape': {
+                    'type': 'structure',
+                    'members': {
+                        'Foo': {'shape': 'StringType', 'hostLabel': True},
+                    },
+                },
+                'StringType': {'type': 'string'},
+            },
+        }
+        self.service_model = ServiceModel(self.model)
+
+    def test_host_prefix_added_to_serialized_request(self):
+        operation_model = self.service_model.operation_model('TestHostPrefixOperation')
+        serializer = serialize.create_serializer('smithy-rpc-v2-cbor')
+
+        params = {'Foo': 'bound'}
+        serialized = serializer.serialize_to_request(params, operation_model)
+
+        self.assertEqual(serialized['host_prefix'], 'bound')
+
+    def test_no_host_prefix_when_not_configured(self):
+        operation_model = self.service_model.operation_model('TestNoHostPrefixOperation')
+        serializer = serialize.create_serializer('smithy-rpc-v2-cbor')
+
+        params = {'Foo': 'bound'}
+        serialized = serializer.serialize_to_request(params, operation_model)
+
+        self.assertNotIn('host_prefix', serialized)
