@@ -12,6 +12,7 @@
 # language governing permissions and limitations under the License.
 import os
 
+from botocore.exceptions import ClientError
 from s3transfer.manager import TransferManager
 
 from awscli.compat import queue
@@ -43,6 +44,7 @@ from awscli.customizations.s3.subscribers import (
     DeleteSourceFileSubscriber,
     DeleteSourceObjectSubscriber,
     DirectoryCreatorSubscriber,
+    ProvideETagSubscriber,
     ProvideLastModifiedTimeSubscriber,
     ProvideSizeSubscriber,
     ProvideUploadContentTypeSubscriber,
@@ -344,6 +346,7 @@ class TestUploadRequestSubmitter(BaseTransferRequestSubmitterTest):
         # Make sure the subscriber applied are of the correct type and order
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProvideUploadContentTypeSubscriber,
             ProgressResultSubscriber,
@@ -381,6 +384,7 @@ class TestUploadRequestSubmitter(BaseTransferRequestSubmitterTest):
         )
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -400,6 +404,7 @@ class TestUploadRequestSubmitter(BaseTransferRequestSubmitterTest):
         upload_call_kwargs = self.transfer_manager.upload.call_args[1]
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -455,6 +460,7 @@ class TestUploadRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.transfer_request_submitter.submit(fileinfo)
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProvideUploadContentTypeSubscriber,
             DeleteSourceFileSubscriber,
@@ -515,6 +521,7 @@ class TestDownloadRequestSubmitter(BaseTransferRequestSubmitterTest):
         # Make sure the subscriber applied are of the correct type and order
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             DirectoryCreatorSubscriber,
             ProvideLastModifiedTimeSubscriber,
@@ -659,6 +666,7 @@ class TestDownloadRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.transfer_request_submitter.submit(fileinfo)
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             DirectoryCreatorSubscriber,
             ProvideLastModifiedTimeSubscriber,
@@ -672,6 +680,38 @@ class TestDownloadRequestSubmitter(BaseTransferRequestSubmitterTest):
         for i, actual_subscriber in enumerate(actual_subscribers):
             self.assertIsInstance(actual_subscriber, ref_subscribers[i])
 
+    def test_skip_download_when_no_overwrite_and_file_exists(self):
+        self.cli_params['no_overwrite'] = True
+        fileinfo = self.create_file_info(self.key)
+        with mock.patch('os.path.exists', return_value=True):
+            future = self.transfer_request_submitter.submit(fileinfo)
+
+        # Result Queue should be empty because it was specified to ignore no-overwrite warnings.
+        self.assertTrue(self.result_queue.empty())
+        # The transfer should be skipped, so future should be None
+        self.assertIsNone(future)
+        self.assert_no_downloads_happened()
+
+    def test_proceed_download_when_no_overwrite_and_file_not_exists(self):
+        self.cli_params['no_overwrite'] = True
+        fileinfo = self.create_file_info(self.key)
+        with mock.patch('os.path.exists', return_value=False):
+            future = self.transfer_request_submitter.submit(fileinfo)
+        # The transfer should proceed, so future should be the transfer manager's return value
+        self.assertIs(self.transfer_manager.download.return_value, future)
+        # And download should have happened
+        self.assertEqual(len(self.transfer_manager.download.call_args_list), 1)
+
+    def test_warn_if_file_exists_without_no_overwrite_flag(self):
+        self.cli_params['no_overwrite'] = False
+        fileinfo = self.create_file_info(self.key)
+        with mock.patch('os.path.exists', return_value=True):
+            future = self.transfer_request_submitter.submit(fileinfo)
+        # The transfer should proceed, so future should be the transfer manager's return value
+        self.assertIs(self.transfer_manager.download.return_value, future)
+        # And download should have happened
+        self.assertEqual(len(self.transfer_manager.download.call_args_list), 1)
+
 
 class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
     def setUp(self):
@@ -712,6 +752,7 @@ class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
         # Make sure the subscriber applied are of the correct type and order
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             SetMetadataDirectivePropsSubscriber,
             SetTagsSubscriber,
@@ -752,6 +793,7 @@ class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
         )
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             SetMetadataDirectivePropsSubscriber,
             SetTagsSubscriber,
@@ -775,6 +817,7 @@ class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
         copy_call_kwargs = self.transfer_manager.copy.call_args[1]
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -900,6 +943,7 @@ class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.transfer_request_submitter.submit(fileinfo)
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             SetMetadataDirectivePropsSubscriber,
             SetTagsSubscriber,
@@ -913,6 +957,22 @@ class TestCopyRequestSubmitter(BaseTransferRequestSubmitterTest):
         for i, actual_subscriber in enumerate(actual_subscribers):
             self.assertIsInstance(actual_subscriber, ref_subscribers[i])
 
+    def test_file_exists_without_no_overwrite(self):
+        self.cli_params['no_overwrite'] = False
+        fileinfo = FileInfo(
+            src=self.source_bucket + "/" + self.source_key,
+            dest=self.bucket + "/" + self.key,
+            operation_name='copy',
+            size=100,
+            source_client=mock.Mock(),
+        )
+        future = self.transfer_request_submitter.submit(fileinfo)
+        # The transfer should proceed, so future should be the transfer manager's return value
+        self.assertIs(self.transfer_manager.copy.return_value, future)
+        self.assertEqual(len(self.transfer_manager.copy.call_args_list), 1)
+        # Head should not be called when no_overwrite is false
+        fileinfo.source_client.head_object.assert_not_called()
+
 
 class TestUploadStreamRequestSubmitter(BaseTransferRequestSubmitterTest):
     def setUp(self):
@@ -947,6 +1007,7 @@ class TestUploadStreamRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.assertEqual(upload_call_kwargs['extra_args'], {})
 
         ref_subscribers = [
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -967,6 +1028,7 @@ class TestUploadStreamRequestSubmitter(BaseTransferRequestSubmitterTest):
 
         ref_subscribers = [
             ProvideSizeSubscriber,
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -1036,6 +1098,7 @@ class TestDownloadStreamRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.assertEqual(download_call_kwargs['extra_args'], {})
 
         ref_subscribers = [
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
@@ -1109,6 +1172,7 @@ class TestDeleteRequestSubmitter(BaseTransferRequestSubmitterTest):
         self.assertEqual(delete_call_kwargs['extra_args'], {})
 
         ref_subscribers = [
+            ProvideETagSubscriber,
             QueuedResultSubscriber,
             ProgressResultSubscriber,
             DoneResultSubscriber,
